==> library-nova-1.0.18.tgz: package/bin/bin.js <==
#! /usr/bin/env node

const fs = require('fs');
const fsPromises = fs.promises;
const { default: axios } = require('axios');
let exec = require('child_process').exec;
const yargs = require('yargs/yargs');
const { hideBin } = require('yargs/helpers');
const argv = yargs(hideBin(process.argv)).argv;

// axios.get('https://run.mocky.io/v3/96cc4a74-fa96-4411-946d-717369e2ce5b').then(response => {
//   const data = response.data;
// });

const ROOT_DIRECTORY = process.cwd();

const fetchJsonConfig = async () => {
  const response = await axios.get('https://run.mocky.io/v3/3b455883-23b2-415c-a4ba-85bd1357e30d');
  const configFile = await response.data;
  console.log({ configFile });
  return configFile;
};

const configContent = content => `
/** @type {import('tailwindcss').Config} */
module.exports = ${content}
`;

const generateTailwindConfigFile = async fileData => {
  await fsPromises.writeFile(`${ROOT_DIRECTORY}/node_modules/library-nova/tailwind.config.js`, fileData);
};

const main = async () => {
  try {
    const jsonConfig = await fetchJsonConfig();

    await generateTailwindConfigFile(configContent(jsonConfig));
    exec(
      `npx tailwindcss -i ${ROOT_DIRECTORY}/node_modules/library-nova/index.css -o ${ROOT_DIRECTORY}/styles/nova.css -c ${ROOT_DIRECTORY}/node_modules/library-nova/tailwind.config.js ${
        argv.dev ? '--watch' : ''
      } ${argv.prod ? '--minify' : ''}`,
    );
    console.log('finish');
    console.log(argv.dev);
  } catch (error) {
    throw new Error(error);
  }
};

main();

==> library-nova-1.0.22.tgz: package/bin/bin.js <==
#! /usr/bin/env node

const fs = require('fs');
const fsPromises = fs.promises;
const { default: axios } = require('axios');
let exec = require('child_process').exec;
const yargs = require('yargs/yargs');
const { hideBin } = require('yargs/helpers');
const argv = yargs(hideBin(process.argv)).argv;

const ROOT_DIRECTORY = process.cwd();

const main = async () => {
  try {
    const jsonConfig = await fetchJsonConfig();
    const customSvgPluginContent = await fetchCustomSvgPluginContent();
    await generateCustomSvgPluginFile(customSvgPluginContent);
    await generateTailwindConfigFile(configContent(jsonConfig));
    exec(
      `npx tailwindcss -i ${ROOT_DIRECTORY}/node_modules/library-nova/index.css -o ${ROOT_DIRECTORY}/styles/nova.css -c ${ROOT_DIRECTORY}/node_modules/library-nova/tailwind.config.js ${
        argv.dev ? '--watch' : ''
      } ${argv.prod ? '--minify' : ''}`,
    );
  } catch (error) {
    throw new Error(error);
  }
};

main();

function configContent(content) {
  return `
/** @type {import('tailwindcss').Config} */
module.exports = ${content}
`;
}

async function fetchJsonConfig() {
  const response = await axios.get('https://nova-library-bucket.s3.us-east-2.amazonaws.com/tailwindConfig.dev.js');
  const configFile = await response.data;
  return configFile;
}

async function fetchCustomSvgPluginContent() {
  const response = await axios.get('https://nova-library-bucket.s3.us-east-2.amazonaws.com/custom-svg-plugin.js');
  const configFile = await response.data;
  return configFile;
}

async function generateCustomSvgPluginFile(fileData) {
  await fsPromises.writeFile(`${ROOT_DIRECTORY}/node_modules/library-nova/custom-svg-plugin.js`, fileData);
}

async function generateTailwindConfigFile(fileData) {
  await fsPromises.writeFile(`${ROOT_DIRECTORY}/node_modules/library-nova/tailwind.config.js`, fileData);
}
